#!/usr/bin/perl
#
# -- MIMEFILTER ---
#
# Perl filter script, that will find, log and remove attachments from mail
# messages. (for the time being it just tells the mailer, not to forward 
# any message containing non-text MIME parts)
#
# v1.0 16.05.2001 (c) Goesta Smekal, EDV-Smekal@chello.at
# please don't hesitate reporting bugs !
#
# The filter is tailored for the XMail daemon, written by Davide Libenzi
# http://www.xmailserver.org
#
# This script is published under the GNU General Public Licence (GPL)

$Status=0;			# default exit status

open (RESULTS, ">>/var/MailRoot/logs/filterlog");

while (<>) {				# read lines from STDIN or file

	if (m/^From/) {				# find the sender
		m/[\w,\.,\-]+@[\w,\.]+/;	# match e-Mail adress
		$From=$&;
		}

	if (m/(^Received: from)/) {		# sending host
		m/\d{1,3}[.]\d{1,3}[.]\d{1,3}[.]\d{1,3}/; # matches an IP adr.
		$Host=$&;
		}

	if (m/(^Date: )(\w{3}.+\d{4})/) { 	# should match RFC 822 Date
		$Date=$2;
		}

	if (m/^MIME-Version:\s+\d{1}\.\d{1}/) {	# according to RFC 2045, MIME
						# messages _must_ contain a
						# line like that
		$Mime="1";			# so it is a MIME message
		}
	
	if ($Mime) {			# now look for attachments
		if (m/(^Content-Type:)(\s+)(\w+)(\/)(\w+)/) {
			if (($3 ne "text") and ($3 ne "multipart")) {	
						# non text content !
				$Reason=$3;	# store type
				$Status=99;	# set xmail response to stop
				}
			}
		}
	}

if ($Reason) {		# report MIME messages, containing "illegal" parts
	print RESULTS "MIME header found in $ARGV\n";
	print RESULTS "  Sender was: $From \n";
	print RESULTS "  from host: $Host \n";
	print RESULTS "  on: $Date \n";
	print RESULTS "Message stopped due to type '$Reason' found.\n";
	print RESULTS "\n";
	}

exit $Status;
